<?php
namespace AIOSEO\Plugin\Common\Main;

use AIOSEO\Plugin\Common\Meta;

/**
 * Outputs anything we need to the head of the site.
 *
 * @since 4.0.0
 */
class Head {
	/**
	 * Class constructor.
	 *
	 * @since 4.0.0
	 */
	public function __construct() {
		if ( is_admin() || wp_doing_ajax() || wp_doing_cron() ) {
			return;
		}

		$this->links        = new Meta\Links();
		$this->robots       = new Meta\Robots();
		$this->keywords     = new Meta\Keywords();
		$this->verification = new Meta\SiteVerification();
		$this->included     = new Meta\Included();
		$this->analytics    = new GoogleAnalytics();
		$this->views        = [
			'meta'   => AIOSEO_DIR . '/app/Common/Views/main/meta.php',
			'social' => AIOSEO_DIR . '/app/Common/Views/main/social.php',
			'schema' => AIOSEO_DIR . '/app/Common/Views/main/schema.php'
		];

		add_action( 'init', [ $this, 'addAnalytics' ] );

		add_filter( 'pre_get_document_title', [ aioseo()->meta->title, 'filterPageTitle' ], 99999 );
		add_action( 'wp_head', [ $this, 'output' ], 1, 0 );
	}

	/**
	 * Adds analytics to the views if needed.
	 *
	 * @since 4.0.0
	 *
	 * @return void
	 */
	public function addAnalytics() {
		if ( $this->analytics->canShowScript() ) {
			$this->views['analytics'] = AIOSEO_DIR . '/app/Common/Views/main/analytics.php';
		}
	}

	/**
	 * The output function itself.
	 *
	 * @since 4.0.0
	 *
	 * @return void
	 */
	public function output() {
		if ( ! $this->included->isIncluded() ) {
			return;
		}

		remove_action( 'wp_head', 'rel_canonical' );

		echo "\n\t\t<!-- " . sprintf(
			'%1$s %2$s',
			esc_html( AIOSEO_PLUGIN_NAME ),
			aioseo()->version // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
		) . " -->\n";

		foreach ( $this->views as $view ) {
			require_once( $view );
		}

		echo "\t\t<!-- " . esc_html( AIOSEO_PLUGIN_NAME ) . " -->\n\n";
	}
}